==> xnu-201.19.tar.gz: xnu-201.19/iokit/Kernel/IOCommand.cpp <==
/*
 * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 * 
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

/*
 *
 *	Copyright (c) 2000 Apple Computer, Inc.  All rights reserved.
 *
 *	HISTORY
 *
 *	11/13/2000		CJS		Created IOCommand class and implementation
 *
 */

#include <IOKit/IOCommand.h>

#define super OSObject
OSDefineMetaClassAndAbstractStructors(IOCommand, OSObject);


//--------------------------------------------------------------------------
//	init -	initialize our data structures
//--------------------------------------------------------------------------

bool IOCommand::init(void)
{
    if (super::init()) {
        queue_init(&fCommandChain);
        return true;
    }
    else
        return false;
}

==> xnu-792.6.22.tar.gz: xnu-792.6.22/iokit/Kernel/IOCommand.cpp <==
/*
 * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 * 
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

/*
 *
 *	Copyright (c) 2000 Apple Computer, Inc.  All rights reserved.
 *
 *	HISTORY
 *
 *	11/13/2000		CJS		Created IOCommand class and implementation
 *
 */

#include <IOKit/IOCommand.h>

#define super OSObject
OSDefineMetaClassAndStructors(IOCommand, OSObject);


//--------------------------------------------------------------------------
//	init -	initialize our data structures
//--------------------------------------------------------------------------

bool IOCommand::init(void)
{
    if (super::init()) {
        queue_init(&fCommandChain);
        return true;
    }
    else
        return false;
}
